============
Geomepy
============
This program is intended at aligning geometries and give back the RMSD value.

***************
usage
***************

usage: geomepy [-h] [-g GEOMS]

optional arguments:
  -h, --help  show this help message and exit

  -g GEOMS, --geoms GEOMS  space separated geometry files to compare in xyz format
